# Django Silly Auth (WIP)

## Why one more authentication system for Django and DRF? again !

I've used a few ones, and did not find the one that behaves the way I want,
efficient, but flexible, I want to win time, and get what I need straight to the point.

The aim of DSA it to provide a good-enough-to-go authentication out of the box, but still remains highly
modular through its SILLY_AUTH config in **settings.py**, so it is always possible to improve your
authentication when you have the time for it.

If you're building a SPA, you can go with DSA as it is at first, and as your work progresses,
switch off the default urls, views and templates to add yours.


<hr>

# [WIKI doc](https://github.com/byoso/django_silly_auth/wiki)

- ## [Read this FIRST](https://github.com/byoso/django_silly_auth/wiki/Must-read-this-few-lines-!)
- ## [Installation](https://github.com/byoso/django_silly_auth/wiki/Installation)

- ## [Configure emails](https://github.com/byoso/django_silly_auth/wiki/Configure-the-emails-of-the-site)

- ## [SILLY_AUTH settings explained](https://github.com/byoso/django_silly_auth/wiki/SILLY_AUTH-settings-explained)

- ## [API Endpoints](https://github.com/byoso/django_silly_auth/wiki/API-endpoints)

- ## [Classic Django](https://github.com/byoso/django_silly_auth/wiki/Classic-Django)
